@@ -44,20 +44,20 @@ class IsModerator(object):
                         return None
                     else:
                         messages.add_message(request, messages.ERROR, _('No puedes eliminar un topic si no eres moderador o admin.'))
-                        return redirect('account_profile')
+                        return redirect('account_login')
 
                 if view_kwargs['topicslug'] and view_kwargs['id'] and (view_func.__name__ == 'PostUpdate' or view_func.__name__ == 'PostDelete'):
                     if utils.es_suyo(request.user, view_kwargs['id']):
                         return None
                     else:
                         messages.add_message(request, messages.ERROR, _('No puedes editar o eliminar un post que no es tuyo.'))
-                        return redirect('account_profile')
+                        return redirect('account_login')
 
                     if utils.es_moderador(request.user, view_kwargs['topicslug']):
                         return None
                     else:
                         messages.add_message(request, messages.ERROR, _('No eres moderador, cuidado con lo que haces.'))
-                        return redirect('account_profile')
+                        return redirect('account_login')
         except:
             return None
 
